@@ -1,4 +1,4 @@
-subscriptions_schema = [
+subscription_schema = [
     "billing_cycle_anchor",
     "billing_thresholds",
     "cancel_at",
